Struct cargo_modules::command::dependencies::options::Options
source · pub struct Options {
pub general: GeneralOptions,
pub project: ProjectOptions,
pub selection: SelectionOptions,
pub acyclic: bool,
pub layout: LayoutAlgorithm,
pub focus_on: Option<String>,
pub max_depth: Option<usize>,
pub cfg_test: bool,
}Fields
general: GeneralOptionsproject: ProjectOptionsselection: SelectionOptionsacyclic: boolRequire graph to be acyclic
layout: LayoutAlgorithmThe graph layout algorithm to use (e.g. none, dot, neato, twopi, circo, fdp, sfdp).
focus_on: Option<String>Focus the graph on a particular path or use-tree’s environment, e.g. “foo::bar::{self, baz, blee::*}”.
max_depth: Option<usize>The maximum depth of the generated graph relative to the crate’s root node, or nodes selected by ‘–focus-on’.
cfg_test: boolAnalyze with #[cfg(test)] enabled (i.e as if built via cargo test).