Struct cargo_modules::options::graph::Options
source · pub struct Options {
pub focus_on: Option<String>,
pub max_depth: Option<usize>,
pub with_types: bool,
pub with_traits: bool,
pub with_fns: bool,
pub with_tests: bool,
pub with_orphans: bool,
}Fields
focus_on: Option<String>Focus the graph on a particular path or use-tree’s environment, e.g. “foo:bar::{self, baz, blee::*}”.
max_depth: Option<usize>The maximum depth of the generated graph relative to the crate’s root node, or nodes selected by ‘–focus-on’.
with_types: boolInclude types (e.g. structs, unions, enums).
with_traits: boolInclude traits (e.g. trait, unsafe trait).
with_fns: boolInclude functions (e.g. fns, async fns, const fns).
with_tests: boolInclude tests (e.g. #[test] fn …).
with_orphans: boolInclude orphaned modules (i.e. unused files in /src).