pub struct Options {
pub general: GeneralOptions,
pub project: ProjectOptions,
pub selection: SelectionOptions,
pub sort_by: SortBy,
pub sort_reversed: bool,
pub focus_on: Option<String>,
pub max_depth: Option<usize>,
pub cfg_test: bool,
}Fields
general: GeneralOptionsproject: ProjectOptionsselection: SelectionOptionssort_by: SortByThe sorting order to use (e.g. name, visibility, kind).
sort_reversed: boolReverses the sorting order.
focus_on: Option<String>Focus the graph on a particular path or use-tree’s environment, e.g. “foo::bar::{self, baz, blee::*}”.
max_depth: Option<usize>The maximum depth of the generated graph relative to the crate’s root node, or nodes selected by ‘–focus-on’.
cfg_test: boolAnalyze with #[cfg(test)] enabled (i.e as if built via cargo test).